# PySPEDAS Examples

This project contains examples and turorials of using pySPEDAS.


## Installation

You can install pyspedas_examples either using conda or using pip:

```
conda install -c spedas pyspedas_examples

or

pip install pyspedas_examples
```


## Use

You can verify that the installation works, using:

```
import pyspedas_examples
from pyspedas_examples.examples.basic.ex_basic import ex_basic
ex_basic()
```

If everything was installed correctly, a plot will appear.


## Additional Information

For pyspedas, see: https://github.com/spedas/pyspedas

For pytplot, see: https://github.com/MAVENSDC/PyTplot

For cdflib, see: https://github.com/MAVENSDC/cdflib

For SPEDAS, see http://spedas.org/
